import * as squint_core from 'squint-cljs/core.js';
import * as cm_clojure from './clojure_mode.mjs';
import * as test_utils from './clojure_mode/test_utils.mjs';
import * as close_brackets from './clojure_mode/extensions/close_brackets.mjs';
import * as commands from './clojure_mode/commands.mjs';
import * as format from './clojure_mode/extensions/formatting.mjs';
import * as assert from 'assert';
var extensions = cm_clojure.default_extensions;
var apply_f = squint_core.partial(test_utils.apply_f, extensions);
var apply_cmd = squint_core.partial(test_utils.apply_cmd, extensions);
null;
null;
// nav
;
assert.equal(apply_f(commands.nav(1), "|()"), "()|");
assert.equal(apply_f(commands.nav(-1), "()|"), "|()");
assert.equal(apply_f(commands.nav(1), "a|b"), "ab|");
assert.equal(apply_f(commands.nav(-1), "a|b"), "|ab");
assert.equal(apply_f(commands.nav(1), "| ab"), " ab|");
assert.equal(apply_f(commands.nav(-1), "ab |"), "|ab ");
assert.equal(apply_f(commands.nav(1), "(|)"), "()|");
assert.equal(apply_f(commands.nav(-1), "(|)"), "|()");
assert.equal(apply_f(commands.nav(1), "a|\nb"), "a\nb|");
// nav_select
;
assert.equal(apply_f(commands.nav_select(1), "|()"), "<()>");
assert.equal(apply_f(commands.nav_select(-1), "()|"), "<()>");
assert.equal(apply_f(commands.nav_select(1), "a|b"), "a<b>");
assert.equal(apply_f(commands.nav_select(1), "(|)"), "<()>");
assert.equal(apply_f(commands.nav_select(1), "\"a|b\""), "\"a<b>\"");
assert.equal(apply_f(commands.nav_select(1), "\"a<b>\""), "<\"ab\">");
assert.equal(apply_f(commands.nav_select(-1), "a|b"), "<a>b");
assert.equal(apply_f(commands.nav_select(1), "| ab"), "< ab>");
assert.equal(apply_f(commands.nav_select(-1), "ab |"), "<ab >");
assert.equal(apply_f(commands.nav_select(1), "(|)"), "<()>");
assert.equal(apply_f(commands.nav_select(-1), "(|)"), "<()>");
assert.equal(apply_f(commands.nav_select(1), "a|\nb"), "a<\nb>");
// close_brackets
;
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "(");
}), "|"), "(|)");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "(");
}), "(|"), "((|)");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "(");
}), "|("), "(|)(");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "(");
}), "|)"), "(|))");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "(");
}), "#|"), "#(|)");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "(");
}), "\"|\""), "\"(|\"");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "|"), "|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "|("), "|(");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "|)"), ")|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "(|)"), "()|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "() |()"), "() ()|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "[(|)]"), "[()|]");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "[()|]"), "[()]|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "([]| s)"), "([] s)|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "(|"), "()|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, "}");
}), "[(|]"), "[(]|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, "]");
}), "((|)"), "(()|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "((|)"), "(())|");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_close(_PERCENT_1, ")");
}), "\"|\""), "\")|\"");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "\"");
}), "|"), "\"|\"");
assert.equal(apply_f((function (_PERCENT_1) {
return close_brackets.handle_open(_PERCENT_1, "\"");
}), "\"|\""), "\"\\\"|\"");
assert.equal(apply_f(close_brackets.handle_backspace, "|"), "|");
assert.equal(apply_f(close_brackets.handle_backspace, "(|"), "|");
assert.equal(apply_f(close_brackets.handle_backspace, "()|"), "(|)");
assert.equal(apply_f(close_brackets.handle_backspace, "#|()"), "|()");
assert.equal(apply_f(close_brackets.handle_backspace, "[[]]|"), "[[]|]");
assert.equal(apply_f(close_brackets.handle_backspace, "(| )"), "|");
assert.equal(apply_f(close_brackets.handle_backspace, "(| a)"), "(| a)");
assert.equal(apply_f(close_brackets.handle_backspace, "@|"), "|");
assert.equal(apply_f(close_brackets.handle_backspace, "@|x"), "|x");
assert.equal(apply_f(close_brackets.handle_backspace, "\"|\""), "|");
assert.equal(apply_f(close_brackets.handle_backspace, "\"\"|"), "\"|\"");
assert.equal(apply_f(close_brackets.handle_backspace, "\"| \""), "\"| \"");
assert.equal(apply_f(close_brackets.handle_backspace, ":x  :a |"), ":x  :a|");
assert.equal(apply_f(close_brackets.handle_backspace, "\"[|]\""), "\"|]\"");
null;
// indentSelection
;
assert.equal(apply_f(format.format, squint_core.str("<", " ()", ">")), squint_core.str("<", "()", ">"));
assert.equal(apply_f(format.format, squint_core.str("<", "(\n)", ">")), squint_core.str("<", "(\n )", ">"));
assert.equal(apply_f(format.format, squint_core.str("<", "(b\n)", ">")), squint_core.str("<", "(b\n  )", ">"));
assert.equal(apply_f(format.format, squint_core.str("<", "(0\n)", ">")), squint_core.str("<", "(0\n )", ">"));
assert.equal(apply_f(format.format, squint_core.str("<", "(:a\n)", ">")), squint_core.str("<", "(:a\n )", ">"));
assert.equal(apply_f(format.format, squint_core.str("<", "(a\n\nb)", ">")), squint_core.str("<", "(a\n  \n  b)", ">"));
assert.equal(apply_f(squint_core.partial(format.prefix_all, "a"), "z|z\nzz|\n|zz"), "az|z\nazz|\n|azz");
assert.equal(apply_f(squint_core.partial(format.prefix_all, "a"), "z<z>\nz<z>"), "az<z>\naz<z>");
// indent_all
;
assert.equal(apply_f(format.indent_all, "| ()"), "|()");
assert.equal(apply_f(format.indent_all, "|()[\n]"), "|()[\n   ]");
assert.equal(apply_f(format.indent_all, "|(\n)"), "|(\n )");
assert.equal(apply_f(format.indent_all, "(<b>\n)"), "(<b>\n  )");
assert.equal(apply_f(format.indent_all, "|(0\nx<)>"), "|(0\n x<)>");
assert.equal(apply_f(format.indent_all, "<(:a\n)>"), "<(:a\n )>");
assert.equal(apply_f(format.indent_all, "|(a\n\nb)"), "|(a\n\n  b)");
// format_all
;
assert.equal(apply_f(format.format_all, "a  :b  3 |"), "a :b 3|");
assert.equal(apply_f(format.format_all, "\"\" |:a "), "\"\" |:a");
assert.equal(apply_f(format.format_all, "(|a )"), "(|a)");
assert.equal(apply_f(format.format_all, "| ( )"), "|()");
assert.equal(apply_f(format.format_all, "|()a"), "|() a");
assert.equal(apply_f(format.format_all, "()  |a"), "() |a");
assert.equal(apply_f(format.format_all, "()|  a"), "()| a");
assert.equal(apply_f(format.format_all, "() | a"), "() |a");
assert.equal(apply_f(format.format_all, "|(\n )"), "|(\n )");
assert.equal(apply_f(format.format_all, "(<b>\n)"), "(<b>\n  )");
assert.equal(apply_f(format.format_all, "<(:a\n)>"), "<(:a\n )>");
assert.equal(apply_f(format.format_all, "|(a\n\nb)"), "|(a\n\n  b)");
assert.equal(apply_f(format.format_all, "|\"a\""), "|\"a\"");
assert.equal(apply_f(format.format_all, "#_a|"), "#_a|");
assert.equal(apply_f(format.format_all, "[ | ]"), "[|]");
assert.equal(apply_f(format.format_all, "|[] "), "|[]");
assert.equal(apply_f(format.format_all, "#(|a )"), "#(|a)");
assert.equal(apply_f(format.format_all, "|@ a"), "|@a");
assert.equal(apply_f(format.format_all, "|&"), "|&");
assert.equal(apply_f(format.format_all, "[_ & |_]"), "[_ & |_]");
assert.equal(apply_f(format.format_all, "|[a [\n]]"), "|[a [\n    ]]");
assert.equal(apply_f(format.format_all, "|[a  [\n]]"), "|[a [\n    ]]");
assert.equal(apply_f(format.format_all, "|[       a \n]"), "|[a\n ]");
assert.equal(apply_f(format.format_all, "|[       a [\n]]"), "|[a [\n    ]]");
assert.equal(apply_f(format.format_all, "|[ \n[ \n[ ]]]"), "|[\n [\n  []]]");
assert.equal(apply_f(format.format_all, "|()[\n]"), "|() [\n    ]");
assert.equal(apply_f(format.format_all, "|()[\n]"), "|() [\n    ]");
// format_selection
;
assert.equal(apply_f(format.format, "<a  b>\nc  d"), "<a b>\nc  d");
assert.equal(apply_f(format.format, "<a>   <b>   c   <d>\na  b"), "<a> <b> c <d>\na  b");
// kill
;
assert.equal(apply_cmd(commands.kill, "| ()\nx"), "|\nx");
assert.equal(apply_cmd(commands.kill, " \"ab|c\" "), "\"ab|\"");
assert.equal(apply_cmd(commands.kill, " \"|a\nb\""), "\"|b\"");
assert.equal(apply_cmd(commands.kill, "(|)"), "(|)");
assert.equal(apply_cmd(commands.kill, "(| x y [])"), "(|)");
assert.equal(apply_cmd(commands.kill, "a| \nb"), "a|b");
// unwrap
;
assert.equal(apply_cmd(commands.unwrap, "(|)"), "|");
assert.equal(apply_cmd(commands.unwrap, "[a | b]"), "a |b");
assert.equal(apply_cmd(commands.unwrap, "a|b"), "a|b");
// balance_ranges
;
assert.equal(apply_f(commands.balance_ranges, "<a>"), "<a>");
assert.equal(apply_f(commands.balance_ranges, "a<bc>"), "a<bc>");
assert.equal(apply_f(commands.balance_ranges, " \"a<\"> "), " <\"a\"> ");
assert.equal(apply_f(commands.balance_ranges, "(<)>"), "<()>");
assert.equal(apply_f(commands.balance_ranges, "(<a) b>"), "<(a) b>");
// slurp
;
assert.equal(apply_f(commands.slurp(1), "(|) a"), "(|a)");
assert.equal(apply_f(commands.slurp(1), "((|)) a"), "((|) a)");
assert.equal(apply_f(commands.slurp(1), "(|) ;;comment\na"), "(|;;comment\n a)");
assert.equal(apply_f(commands.slurp(-1), "a(|)"), "(a|)");
assert.equal(apply_f(commands.slurp(-1), "a ;; hello\n(|)"), "(a ;; hello\n | )");
assert.equal(apply_f(commands.slurp(-1), "a #:b{|}"), "#:b{a|}");
assert.equal(apply_f(commands.slurp(-1), "a #(|)"), "#(a|)");
assert.equal(apply_f(commands.slurp(1), "#(|) a"), "#(|a)");
assert.equal(apply_f(commands.slurp(1), "@(|) a"), "@(|a)");
assert.equal(apply_f(commands.slurp(1), "#::a{|:a} 1"), "#::a{|:a 1}");
assert.equal(apply_f(commands.slurp(1), "'(|) 1"), "'(|1)");
assert.equal(apply_f(commands.slurp(1), "^{|}    :x :a "), "^{|:x} :a");
assert.equal(apply_f(commands.slurp(1), "^{|}    :x 1"), "^{|:x} 1");
assert.equal(apply_f(commands.slurp(1), "^{} [|] :x"), "^{} [|:x]");
assert.equal(apply_f(commands.slurp(1), "('is-d|ata) :x"), "('is-d|ata :x)");
assert.equal(apply_f(commands.slurp(1), "('xy|z 1) 2"), "('xy|z 1 2)");
assert.equal(apply_f(commands.slurp(1), "'ab|c 1"), "'ab|c 1");
null;
// barf
;
assert.equal(apply_f(commands.barf(1), "(|a)"), "(|) a");
assert.equal(apply_f(commands.barf(-1), "(|a)"), "a (|)");
assert.equal(apply_f(commands.barf(1), "((|)a)"), "((|)a)");
assert.equal(apply_f(commands.barf(-1), "#(|a)"), "a #(|)");
assert.equal(apply_f(commands.barf(1), "#(|a)"), "#(|) a");
assert.equal(apply_f(commands.barf(-1), "#:b{a|}"), "a #:b{|}");
// grow_selections
;
assert.equal(apply_cmd(commands.selection_grow, "(|)"), "<()>");
assert.equal(apply_cmd(commands.selection_grow, "(|a)"), "(<a>)");
assert.equal(apply_cmd(commands.selection_grow, "(a|)"), "(<a>)");
assert.equal(apply_cmd(commands.selection_grow, "\"|\""), "<\"\">");
assert.equal(apply_cmd(commands.selection_grow, "\"a|b\""), "\"<ab>\"");
assert.equal(apply_cmd(commands.selection_grow, "[|]"), "<[]>");
assert.equal(apply_cmd(commands.selection_grow, ";; hell|o"), "<;; hello>");
assert.equal(apply_cmd(commands.selection_grow, "( a|)"), "( <a>)");
assert.equal(apply_cmd(commands.selection_grow, "( <a>)"), "(< a>)");
assert.equal(apply_cmd(commands.selection_grow, "(< a>)"), "<( a)>");
assert.equal(apply_cmd(commands.selection_grow, "@<deref>"), "<@deref>");
// enter_and_indent
;
assert.equal(apply_cmd(commands.enter_and_indent, "(|)"), "(\n |)");
assert.equal(apply_cmd(commands.enter_and_indent, "((|))"), "((\n  |))");
assert.equal(apply_cmd(commands.enter_and_indent, "(()|)"), "(()\n |)");
assert.equal(apply_cmd(commands.enter_and_indent, "(a |b)"), "(a\n  |b)");
assert.equal(apply_cmd(commands.enter_and_indent, "(a b|c)"), "(a b\n  |c)");

export { extensions, apply_f, apply_cmd }
